@@ -8,17 +8,14 @@ import jsii
 import publication
 import typing_extensions
 
-from typeguard import check_type
-
-import aws_cdk.aws_iam._jsii
-import aws_cdk.core._jsii
+import aws_cdk._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@renovosolutions/cdk-library-managed-instance-role",
-    "1.0.318",
+    "2.1.3",
     __name__[0:-6],
-    "cdk-library-managed-instance-role@1.0.318.jsii.tgz",
+    "cdk-library-managed-instance-role@2.1.3.jsii.tgz",
 )
 
 __all__ = [
